#update {
      margin:10px 40px;
}

.button {
      display: inline-block;
      outline: none;
      cursor: pointer;
      text-align: center;
      text-decoration: none;
      font: 14px / 100% Arial, Helvetica, sans-serif;
      padding: 0.5em 1em 0.55em;
      text-shadow: 0px 1px 1px rgba(0, 0, 0, 0.3);
      -webkit-border-radius: 0.5em;
      -moz-border-radius: 0.5em;
      border-radius: 0.5em;
      -webkit-box-shadow: 0px 1px 2px rgba(0, 0, 0, 0.2);
      -moz-box-shadow: 0px 1px 2px rgba(0, 0, 0, 0.2);
      box-shadow: 0px 1px 2px rgba(0, 0, 0, 0.2);
}

.button:hover {
      text-decoration: none;
}

.button:active {
      position: relative;
      top: 1px;
}

/* white */
.white {
      color: #606060;
      border: solid 1px #b7b7b7;
      background: #fff;
      background: -webkit-gradient(linear, left top, left bottom, from(#fff), to(#ededed));
      background: -moz-linear-gradient(top,  #fff,  #ededed);
      filter:  progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff', endColorstr='#ededed');
}

.white:hover {
      background: #ededed;
      background: -webkit-gradient(linear, left top, left bottom, from(#fff), to(#dcdcdc));
      background: -moz-linear-gradient(top,  #fff,  #dcdcdc);
      filter:  progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff', endColorstr='#dcdcdc');
}

.white:active {
      color: #999;
      background: -webkit-gradient(linear, left top, left bottom, from(#ededed), to(#fff));
      background: -moz-linear-gradient(top,  #ededed,  #fff);
      filter:  progid:DXImageTransform.Microsoft.gradient(startColorstr='#ededed', endColorstr='#ffffff');
}


.tip {
       text-align: left;
       width:auto;
       max-width:500px;
}

.tip-title {
      font-size: 11px;
      text-align:center;
      margin-bottom:2px;
}

#right-container {
      display: none;
}

#center-container {
      width:800px;
}

#infovis {
      width:800px;
}


