"""
This package contains the basic jit widgets.

Get this source from http://github.com/ralphbean/tw2.jit
"""

#TODO -- this is *not* the right way to do this.
jit_base = "static/Jit-2.0.0a"

from widgets import (AreaChart, BarChart, PieChart,
                     TreeMap, ForceDirectedGraph, RadialGraph,
                     Sunburst, Icicle, SpaceTree, HyperTree)

from widgets import AjaxRadialGraph

from widgets import SQLARadialGraph
